@@ -9,30 +9,31 @@ import wgdi
 import wgdi.base as base
 from wgdi.align_dotplot import align_dotplot
 from wgdi.block_correspondence import block_correspondence
-from wgdi.polyploidy_classification import polyploidy_classification
 from wgdi.block_info import block_info
 from wgdi.block_ks import block_ks
 from wgdi.circos import circos
 from wgdi.dotplot import dotplot
+from wgdi.karyotype import karyotype
+from wgdi.karyotype_mapping import karyotype_mapping
 from wgdi.ks import ks
 from wgdi.ks_peaks import kspeaks
 from wgdi.ksfigure import ksfigure
 from wgdi.peaksfit import peaksfit
 from wgdi.pindex import pindex
+from wgdi.polyploidy_classification import polyploidy_classification
 from wgdi.retain import retain
 from wgdi.run_colliearity import mycollinearity
 from wgdi.trees import trees
 
+
 parser = argparse.ArgumentParser(
     prog='wgdi', usage='%(prog)s [options]', epilog="", formatter_class=argparse.RawDescriptionHelpFormatter,)
 parser.description = '''\
-This is a gold standard for complex genomic analysis,including the construction 
-of homologous gene dotplot, event-related genomic alignment, and synonymous 
-substitutions, and differences in different evolution rates, etc.
+WGDI(Whole-Genome Duplication Integrated analysis) is a Python-based command-line tool that facilitates comprehensive analysis of recursive polyploidization events and cross-species genome alignments. 
 
     https://wgdi.readthedocs.io/en/latest/
     -------------------------------------- '''
-parser.add_argument("-v", "--version", action='version', version='0.4.7')
+parser.add_argument("-v", "--version", action='version', version='0.4.9')
 parser.add_argument("-d", dest="dotplot",
                     help="Show homologous gene dotplot")
 parser.add_argument("-icl", dest="improvedcollinearity",
@@ -55,6 +56,10 @@ parser.add_argument("-pc", dest="polyploidy_classification",
                     help="Polyploid distinguish among subgenomes")
 parser.add_argument("-a", dest="alignment",
                     help="Show event-related genomic alignment in a dotplot")
+parser.add_argument("-k", dest="karyotype",
+                    help="Show genome evolution from reconstructed ancestors")
+parser.add_argument("-km", dest="karyotype_mapping",
+                    help="Mapping from the known karyotype result to this species")
 parser.add_argument("-at", dest="alignmenttrees",
                     help="Collinear genes construct phylogenetic trees")
 parser.add_argument("-p", dest="pindex",
@@ -68,119 +73,39 @@ parser.add_argument("-conf", dest="configure",
 args = parser.parse_args()
 
 
-def run_dotplot():
-    options = base.load_conf(args.dotplot, 'dotplot')
-    dot = dotplot(options)
-    dot.run()
-
-
-def run_block_info():
-    options = base.load_conf(args.blockinfo, 'blockinfo')
-    blockinfo = block_info(options)
-    blockinfo.run()
-
-
-def run_circos():
-    options = base.load_conf(args.circos, 'circos')
-    cir = circos(options)
-    cir.run()
-
-
-def run_peaksfit():
-    options = base.load_conf(args.peaksfit, 'peaksfit')
-    pf = peaksfit(options)
-    pf.run()
-
-
-def run_align_dotplot():
-    options = base.load_conf(args.alignment, 'alignment')
-    align_dot = align_dotplot(options)
-    align_dot.run()
-
-
-def run_align_correspondence():
-    options = base.load_conf(args.correspondence, 'correspondence')
-    align_cor = block_correspondence(options)
-    align_cor.run()
-
-
-def run_retain():
-    options = base.load_conf(args.retain, 'retain')
-    retained = retain(options)
-    retained.run()
-
-
-def run_block_ks():
-    options = base.load_conf(args.blockks, 'blockks')
-    blockks = block_ks(options)
-    blockks.run()
-
-
-def run_kspeaks():
-    options = base.load_conf(args.kspeaks, 'kspeaks')
-    kp = kspeaks(options)
-    kp.run()
-
-
-def run_ksfigure():
-    options = base.load_conf(args.ksfigure, 'ksfigure')
-    kf = ksfigure(options)
-    kf.run()
-
-def run_polyploidy_classification():
-    options = base.load_conf(args.polyploidy_classification, 'polyploidy classification')
-    pc = polyploidy_classification(options)
-    pc.run()
-
-
-def run_pindex():
-    options = base.load_conf(args.pindex, 'pindex')
-    p = pindex(options)
-    p.run()
-
-
-def run_trees():
-    options = base.load_conf(args.alignmenttrees, 'alignmenttrees')
-    t = trees(options)
-    t.run()
-
-
-def run_cal_ks():
-    options = base.load_conf(args.calks, 'ks')
-    calks = ks(options)
-    calks.run()
-
-
-def run_collinearity():
-    options = base.load_conf(args.improvedcollinearity, 'collinearity')
-    col = mycollinearity(options)
-    col.run()
+def run_subprogram(program, conf, name):
+    options = base.load_conf(conf, name)
+    r = program(options)
+    r.run()
 
 
 def run_configure():
     base.rewrite(args.configure, 'ini')
 
 
-def module_to_run(argument):
+def module_to_run(argument, conf):
     switcher = {
-        'dotplot': run_dotplot,
-        'correspondence': run_align_correspondence,
-        'alignment': run_align_dotplot,
-        'retain': run_retain,
-        'blockks': run_block_ks,
-        'blockinfo': run_block_info,
-        'calks': run_cal_ks,
-        'circos': run_circos,
-        'kspeaks': run_kspeaks,
-        'peaksfit': run_peaksfit,
-        'ksfigure': run_ksfigure,
-        'pindex': run_pindex,
-        'alignmenttrees': run_trees,
-        'improvedcollinearity': run_collinearity,
+        'dotplot': (dotplot, conf, 'dotplot'),
+        'correspondence': (block_correspondence, conf, 'correspondence'),
+        'alignment': (align_dotplot, conf, 'alignment'),
+        'retain': (retain, conf, 'retain'),
+        'blockks': (block_ks, conf, 'blockks'),
+        'blockinfo': (block_info, conf, 'blockinfo'),
+        'calks': (ks, conf, 'ks'),
+        'circos': (circos, conf, 'circos'),
+        'kspeaks': (kspeaks, conf, 'kspeaks'),
+        'peaksfit': (peaksfit, conf, 'peaksfit'),
+        'ksfigure': (ksfigure, conf, 'ksfigure'),
+        'pindex': (pindex, conf, 'pindex'),
+        'alignmenttrees': (trees, conf, 'alignmenttrees'),
+        'improvedcollinearity': (mycollinearity, conf, 'collinearity'),
         'configure': run_configure,
-        'polyploidy_classification':run_polyploidy_classification,
+        'polyploidy_classification': (polyploidy_classification, conf, 'polyploidy classification'),
+        'karyotype': (karyotype, conf, 'karyotype'),
+        'karyotype_mapping': (karyotype_mapping, conf, 'karyotype_mapping'),
     }
-    return switcher.get(argument)()
+    program, conf, name = tuple(switcher.get(argument))
+    run_subprogram(program, conf, name)
 
 
 def main():
@@ -200,7 +125,9 @@ def main():
                'peaksfit': 'peaksfit.conf',
                'configure': 'conf.ini',
                'improvedcollinearity': 'collinearity.conf',
-               'polyploidy_classification':'polyploidy_classification.conf',
+               'polyploidy_classification': 'polyploidy_classification.conf',
+               'karyotype': 'karyotype.conf',
+               'karyotype_mapping': 'karyotype_mapping.conf',
                }
     for arg in vars(args):
         value = getattr(args, arg)
@@ -210,9 +137,10 @@ def main():
                 print(f.read())
                 if arg == 'ksfigure':
                     if not os.path.exists('ks_fit_result.csv'):
-                        shutil.copy2(os.path.join(wgdi.__path__[0], 'example/ks_fit_result.csv'), os.getcwd())
+                        shutil.copy2(os.path.join(
+                            wgdi.__path__[0], 'example/ks_fit_result.csv'), os.getcwd())
             elif not os.path.exists(value):
                 print(value+' not exits')
                 sys.exit(0)
             else:
-                module_to_run(arg)
+                module_to_run(arg, value)
